# Based on
# https://src.fedoraproject.org/rpms/dbcsr
# https://src.fedoraproject.org/rpms/MUSIC
%global mpi_list mpich openmpi
 
Name:           extrae
Version:        4.0.6
Release:        1%{?dist}
Summary:        Parallel runtime instrumentation framework

License:        LGPL-2.1-or-later
URL:            https://tools.bsc.es/extrae
Source0:        https://github.com/bsc-performance-tools/extrae/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires: autoconf
BuildRequires: binutils-devel
BuildRequires: boost-devel
BuildRequires: chrpath
BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: gcc-gfortran
BuildRequires: glibc-devel
BuildRequires: elfutils-devel
BuildRequires: elfutils-libelf-devel
BuildRequires: libdwarf-devel
BuildRequires: libpfm-devel
BuildRequires: libtool
BuildRequires: libunwind-devel
BuildRequires: libxml2-devel
BuildRequires: mpich-devel
BuildRequires: openmpi-devel
BuildRequires: papi-devel 
BuildRequires: zlib-devel

# papi is currently not built for s390
# OpenMPI not supported on i686 and an unexpected test fails
ExcludeArch: s390 s390x %{ix86}

%description
A dynamic instrumentation package to trace programs compiled and run with the
shared memory model (like OpenMP and pthreads), the message passing (MPI)
programming model or both programming models (different MPI processes using
OpenMP or pthreads within each MPI process). **Extrae** generates trace files
that can be later visualized with **Paraver**.

%package devel

Summary:        Parallel runtime instrumentation framework
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Development header files for Extrae

%package docs
Summary:         Parallel runtime instrumentation framework

%description docs
Example files for using Extrae

%package openmpi
Summary: Extrae - openmpi version
BuildRequires:  openmpi-devel

%description openmpi
This package contains the parallel single- and multi-threaded versions
using OpenMPI.
 
%package openmpi-devel
Summary: Development files for %{name}-openmpi
Requires: %{name}-openmpi%{?_isa} = %{version}-%{release}
 
%description openmpi-devel
The %{name}-openmpi-devel package contains libraries and header files for
developing applications that use %{name}-openmpi.

%package openmpi-docs
Summary:         Parallel runtime instrumentation framework
Requires: openmpi
 
%description openmpi-docs
Example files for using Extrae with OpenMPI

%package mpich
Summary: Extrae - mpich version
BuildRequires:  mpich-devel

%description mpich
This package contains the parallel single- and multi-threaded versions
using mpich.

%package mpich-devel
Summary: Development files for %{name}-mpich
Requires: %{name}-mpich%{?_isa} = %{version}-%{release}

%description mpich-devel	
The %{name}-mpich-devel package contains libraries and header files for
developing applications that use %{name}-mpich.

%package mpich-docs
Summary:         Parallel runtime instrumentation framework
Requires:  mpich

%description mpich-docs
Example files for using Extrae with MPICH


%prep
%autosetup -c -n %{name}-%{version} -N
# Need to create separate build directories for each build

pushd %{name}-%{version}
# fix to use build path
sed -i 's|${prefix}/|$(DESTDIR)$(prefix)/|g' \
 src/extrae-uncore/Makefile.am
# Do not include build directory path
sed -i 's|EXTRAE_ONLINE_SOURCES=$(DESTDIR)|EXTRAE_ONLINE_SOURCES=|g' \
 etc/Makefile.am
sed -i 's|"@sub_EXTRAE_HOME@" "$(DESTDIR)$(prefix)"|"@sub_EXTRAE_HOME@" "$(prefix)"|g' \
 tests/overhead/Makefile.am
# Do not run tests that use PAPI as not available in a VM
sed -i '/ALLTESTS += check_Extrae_xml_envvar_counters.sh/d' \
 tests/functional/xml/Makefile.am 
sed -i '/SUBDIRS += hw-counters/d' tests/functional/Makefile.am
# Pthreads test also fails in Fedora CI unclear why, reported,
# but found to be ok on normal Fedora instance
# https://github.com/bsc-performance-tools/extrae/issues/95
sed -i '/SUBDIRS += PTHREAD/d' tests/functional/tracer/Makefile.am
# Exclude failing MPI tests, reported:
# https://github.com/bsc-performance-tools/extrae/issues/98
sed -i '/mpi_commranksize_f_1proc.sh/d ' \
 tests/functional/tracer/MPI/Makefile.am
sed -i '/mpi_commranksize_f/d' tests/functional/tracer/MPI/Makefile.am
sed -i '/mpi_isendirecvwaitall_c.sh/d' tests/functional/tracer/MPI/Makefile.am
sed -i '/mpi_isendirecvwaitall_c/d' tests/functional/tracer/MPI/Makefile.am
sed -i '/mpi_isendirecv_c.sh/d' tests/functional/tracer/MPI/Makefile.am
sed -i '/mpi_isendirecv_c/d' tests/functional/tracer/MPI/Makefile.am
sed -i '/mpi_sendirecv_c.sh/d' tests/functional/tracer/MPI/Makefile.am
sed -i '/mpi_sendirecv_c/d' tests/functional/tracer/MPI/Makefile.am
# Do not test on 4 processors, may only have upto 2
sed -i '/mpi_initfini_c_linked_4proc.sh/d' tests/functional/tracer/MPI/Makefile.am

# Use a relative link
sed -i 's|ln -fs|ln -r -s|g' src/extrae-uncore/Makefile.am
 
# add missing declarations
# https://github.com/bsc-performance-tools/extrae/pull/94
sed -i '/void Extrae_IntelPEBS_setLoadL3MSampling (int enabled);/a void Extrae_IntelPEBS_setOffcoreStoreL3MSampling(int enabled);' \
 src/tracer/sampling/intel-pebs/sampling-intel-pebs.h
# https://github.com/bsc-performance-tools/extrae/pull/97
sed -i '/#include <mpi.h>/a #include <unistd.h>' \
 tests/functional/tracer/MPI/mpi_sendirecviprobewait_c.c
popd

for mpi in %{mpi_list}
do
 cp -a -p %{name}-%{version} %{name}-%{version}-$mpi
done

%build
pushd %{name}-%{version}
autoreconf -fi
%configure --prefix=%{_prefix} \
           --disable-rpath \
           --enable-openmp \
           --without-mpi \
           --with-papi=%{_prefix} \
           --with-papi-libs=%{_libdir} \
           --with-papi-headers=%{_includedir} \
           --with-binutils=%{_prefix} \
           --with-unwind=%{_prefix} \
           --with-xml-prefix=%{_prefix} \
           --with-dwarf-prefix=%{_prefix} \
           --with-dwarf-binaries=%{_bindir} \
           --with-elf=%{_prefix} \
           --with-boost=%{_prefix} \
           --without-dyninst \
           --disable-static

%make_build
popd

for mpi in %{mpi_list}
do
  module load mpi/$mpi-%{_arch}
  pushd %{name}-%{version}-$mpi
  autoreconf -fi
  ./configure --prefix=$MPI_HOME \
             --disable-rpath \
             --enable-openmp \
             --with-mpi=$MPI_HOME \
             --with-mpi-binaries=$MPI_BIN \
             --with-mpi-libs=$MPI_LIB \
             --with-mpi-headers=%{_includedir}/$mpi-%{_arch} \
             --with-papi=%{_prefix} \
             --with-papi-libs=%{_libdir} \
             --with-papi-headers=%{_includedir} \
             --with-binutils=%{_prefix} \
             --with-unwind=%{_prefix} \
             --with-xml-prefix=%{_prefix} \
             --with-dwarf-prefix=%{_prefix} \
             --with-dwarf-binaries=%{_bindir} \
             --with-elf=%{_prefix} \
             --with-boost=%{_prefix} \
             --without-dyninst \
             --disable-static
  %make_build
  popd
  module purge
done

%install
pushd %{name}-%{version}
%make_install
chrpath --delete %{buildroot}%{_bindir}/mpi2prv
chrpath --delete %{buildroot}%{_bindir}/extrae-cmd
chrpath --delete %{buildroot}%{_libdir}/libseqtrace-%{version}.so
chrpath --delete %{buildroot}%{_libdir}/libomptrace-%{version}.so
chrpath --delete %{buildroot}%{_libdir}/libsmpsstrace-%{version}.so
chrpath --delete %{buildroot}%{_libdir}/libnanostrace-%{version}.so
chrpath --delete %{buildroot}%{_libdir}/libpttrace-%{version}.so

mkdir -p %{buildroot}%{_datadir}/extrae
mv %{buildroot}%{_datadir}/example %{buildroot}%{_datadir}/extrae/example
mv %{buildroot}%{_datadir}/tests %{buildroot}%{_datadir}/extrae/tests
popd

for mpi in %{mpi_list}
do
  module load mpi/$mpi-%{_arch}
  pushd %{name}-%{version}-$mpi
  %make_install
  chrpath --delete %{buildroot}$MPI_LIB/libsmpsstrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libsmpssmpitracef-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libsmpssmpitracecf-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libsmpssmpitrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libseqtrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libpttrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libptmpitracef-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libptmpitracecf-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libptmpitrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libomptrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libompitracef-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libompitracecf-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libompitrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libnanostrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libnanosmpitracef-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libnanosmpitracecf-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libnanosmpitrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libmpitracef-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libmpitracecf-%{version}.so
  chrpath --delete %{buildroot}$MPI_LIB/libmpitrace-%{version}.so
  chrpath --delete %{buildroot}$MPI_BIN/mpimpi2prv
  chrpath --delete %{buildroot}$MPI_BIN/mpi2prv
  chrpath --delete %{buildroot}$MPI_BIN/extrae-cmd


  mkdir -p %{buildroot}$MPI_HOME/share/extrae
  mv %{buildroot}$MPI_HOME/share/example %{buildroot}$MPI_HOME/share/extrae/example
  mv %{buildroot}$MPI_HOME/share/tests %{buildroot}$MPI_HOME/share/extrae/tests
  popd
  module purge
done

%check
pushd %{name}-%{version}
export EXTRAE_ON=1
EXTRAE_ON=1 make check
popd
for mpi in %{mpi_list}
do
  module load mpi/$mpi-%{_arch}
  pushd %{name}-%{version}-$mpi
  export EXTRAE_ON=1
  EXTRAE_ON=1 make check
  popd
  module purge
done

%files
%license %{name}-%{version}/COPYING
%doc %{name}-%{version}/README
%doc %{name}-%{version}/ChangeLog
%doc %{name}-%{version}/AUTHORS
%{_sysconfdir}/configured.sh
%{_sysconfdir}/extrae-vars.sh
%{_sysconfdir}/extrae.sh
%{_sysconfdir}/extrae_uncore_template.xml
%{_bindir}/extrae-cmd
%{_bindir}/extrae-header
%{_bindir}/extrae-loader
%{_bindir}/extrae-uncore
%{_bindir}/extrae-uncore.py
%{_bindir}/extrae_static
%{_bindir}/genmpits
%{_bindir}/mpi2dim
%{_bindir}/mpi2prv
%{_bindir}/papi_best_set
%{_bindir}/reducempit
%{_bindir}/uncore-service-seq
%{_libdir}/libnanostrace-4.0.6.so
%{_libdir}/libomptrace-4.0.6.so
%{_libdir}/libpttrace-4.0.6.so
%{_libdir}/libseqtrace-4.0.6.so
%{_libdir}/libsmpsstrace-4.0.6.so
%dir %{_libexecdir}/pyextrae
%{_libexecdir}/pyextrae/__init__.py
%dir %{_libexecdir}/pyextrae/common
%{_libexecdir}/pyextrae/common/__init__.py
%{_libexecdir}/pyextrae/common/extrae.py
%dir %{_libexecdir}/pyextrae/multiprocessing
%{_libexecdir}/pyextrae/multiprocessing/__init__.py
%dir %{_libexecdir}/pyextrae/profile
%{_libexecdir}/pyextrae/profile/__init__.py
%dir %{_libexecdir}/pyextrae/pthreads
%{_libexecdir}/pyextrae/pthreads/__init__.py
%dir %{_libexecdir}/pyextrae/sequential
%{_libexecdir}/pyextrae/sequential/__init__.py

%files devel
%{_includedir}/Makefile.extrae_module
%{_includedir}/extrae.h
%{_includedir}/extrae_internals.h
%{_includedir}/extrae_module.f90
%{_includedir}/extrae_types.h
%{_includedir}/extrae_user_events.h
%{_includedir}/extrae_version.h
%{_includedir}/extraef.h
%{_includedir}/extraef_user_events.h
%{_includedir}/mpitrace_user_events.h
%{_includedir}/mpitracef_user_events.h
%{_libdir}/libnanostrace.so
%{_libdir}/libomptrace.so
%{_libdir}/libpttrace.so
%{_libdir}/libseqtrace.so
%{_libdir}/libsmpsstrace.so

%files docs
%license %{name}-%{version}/COPYING
%dir %{_datadir}/extrae
%dir %{_datadir}/extrae/example
%dir %{_datadir}/extrae/example/FORK
%{_datadir}/extrae/example/FORK/Makefile
%{_datadir}/extrae/example/FORK/Makefile.inc
%{_datadir}/extrae/example/FORK/README
%{_datadir}/extrae/example/FORK/extrae.xml
%{_datadir}/extrae/example/FORK/function-list
%{_datadir}/extrae/example/FORK/pi_forked.c
%{_datadir}/extrae/example/FORK/run_dyninst.sh
%{_datadir}/extrae/example/Makefile.inc
%dir %{_datadir}/extrae/example/OMP
%{_datadir}/extrae/example/OMP/Makefile
%{_datadir}/extrae/example/OMP/Makefile.inc
%{_datadir}/extrae/example/OMP/README
%{_datadir}/extrae/example/OMP/extrae.xml
%{_datadir}/extrae/example/OMP/pi.c
%{_datadir}/extrae/example/OMP/pi_instrumented.c
%{_datadir}/extrae/example/OMP/run_dyninst.sh
%{_datadir}/extrae/example/OMP/run_instrumented.sh
%{_datadir}/extrae/example/OMP/run_ldpreload.sh
%dir %{_datadir}/extrae/example/OMPSS
%{_datadir}/extrae/example/OMPSS/Makefile
%{_datadir}/extrae/example/OMPSS/Makefile.inc
%{_datadir}/extrae/example/OMPSS/extrae.xml
%{_datadir}/extrae/example/OMPSS/heat-ompss.c
%{_datadir}/extrae/example/OMPSS/heat.h
%{_datadir}/extrae/example/OMPSS/job.lsf
%{_datadir}/extrae/example/OMPSS/misc.c
%{_datadir}/extrae/example/OMPSS/solver-ompss.c
%{_datadir}/extrae/example/OMPSS/test.dat
%{_datadir}/extrae/example/OMPSS/trace.sh
%dir %{_datadir}/extrae/example/PTHREAD
%{_datadir}/extrae/example/PTHREAD/Makefile
%{_datadir}/extrae/example/PTHREAD/Makefile.inc
%{_datadir}/extrae/example/PTHREAD/README
%{_datadir}/extrae/example/PTHREAD/extrae.xml
%{_datadir}/extrae/example/PTHREAD/pthread-example.c
%{_datadir}/extrae/example/PTHREAD/user-comms.c
%dir %{_datadir}/extrae/example/PYTHON
%{_datadir}/extrae/example/PYTHON/extrae.xml
%{_datadir}/extrae/example/PYTHON/function-list
%{_datadir}/extrae/example/PYTHON/run.sh
%{_datadir}/extrae/example/PYTHON/test.py
%dir %{_datadir}/extrae/example/SEQ
%{_datadir}/extrae/example/SEQ/Makefile
%{_datadir}/extrae/example/SEQ/Makefile.inc
%{_datadir}/extrae/example/SEQ/README
%{_datadir}/extrae/example/SEQ/extrae.xml
%{_datadir}/extrae/example/SEQ/function-list
%{_datadir}/extrae/example/SEQ/pi.c
%{_datadir}/extrae/example/SEQ/pi_instrumented.c
%{_datadir}/extrae/example/SEQ/pi_instrumented.f90
%{_datadir}/extrae/example/SEQ/run_dyninst.sh
%{_datadir}/extrae/example/SEQ/run_instrumented.sh
%{_datadir}/extrae/example/SEQ/run_instrumentedf.sh
%dir %{_datadir}/extrae/example/UNICORE
%dir %{_datadir}/extrae/example/UNICORE/MPI
%{_datadir}/extrae/example/UNICORE/MPI/extrae.xml
%dir %{_datadir}/extrae/example/UNICORE/SEQ
%{_datadir}/extrae/example/UNICORE/SEQ/extrae.xml
%dir %{_datadir}/extrae/tests
%dir %{_datadir}/extrae/tests/overhead
%{_datadir}/extrae/tests/overhead/JavaEvent.java
%{_datadir}/extrae/tests/overhead/JavaFakeRoutine.java
%{_datadir}/extrae/tests/overhead/JavaNEvent4.java
%{_datadir}/extrae/tests/overhead/Makefile
%{_datadir}/extrae/tests/overhead/extrae.xml
%{_datadir}/extrae/tests/overhead/extrae_event.c
%{_datadir}/extrae/tests/overhead/extrae_eventandcounters.c
%{_datadir}/extrae/tests/overhead/extrae_get_caller1.c
%{_datadir}/extrae/tests/overhead/extrae_get_caller6.c
%{_datadir}/extrae/tests/overhead/extrae_nevent4.c
%{_datadir}/extrae/tests/overhead/extrae_trace_callers.c
%{_datadir}/extrae/tests/overhead/extrae_user_function.c
%{_datadir}/extrae/tests/overhead/extraej.xml
%{_datadir}/extrae/tests/overhead/extraej_functionlist
%{_datadir}/extrae/tests/overhead/ia32_rdtsc_clock.c
%{_datadir}/extrae/tests/overhead/papi_read1.c
%{_datadir}/extrae/tests/overhead/papi_read4.c
%{_datadir}/extrae/tests/overhead/posix_clock.c
%{_datadir}/extrae/tests/overhead/ppc_clock.c
%{_datadir}/extrae/tests/overhead/run_overhead_tests.sh

%files mpich
%license %{name}-%{version}/COPYING
%doc %{name}-%{version}/README
%doc %{name}-%{version}/ChangeLog
%doc %{name}-%{version}/AUTHORS
%{_libdir}/mpich/bin/extrae-cmd
%{_libdir}/mpich/bin/extrae-header
%{_libdir}/mpich/bin/extrae-loader
%{_libdir}/mpich/bin/extrae-uncore
%{_libdir}/mpich/bin/extrae-uncore.py
%{_libdir}/mpich/bin/extrae_static
%{_libdir}/mpich/bin/genmpits
%{_libdir}/mpich/bin/mpi2dim
%{_libdir}/mpich/bin/mpi2prv
%{_libdir}/mpich/bin/mpimpi2dim
%{_libdir}/mpich/bin/mpimpi2prv
%{_libdir}/mpich/bin/papi_best_set
%{_libdir}/mpich/bin/reducempit
%{_libdir}/mpich/bin/uncore-service-mpi
%{_libdir}/mpich/bin/uncore-service-seq
%dir %{_libdir}/mpich/etc
%{_libdir}/mpich/etc/configured.sh
%{_libdir}/mpich/etc/extrae-vars.sh
%{_libdir}/mpich/etc/extrae.sh
%{_libdir}/mpich/etc/extrae_uncore_template.xml
%{_libdir}/mpich/lib/libmpitrace-4.0.6.so
%{_libdir}/mpich/lib/libmpitracecf-4.0.6.so
%{_libdir}/mpich/lib/libmpitracef-4.0.6.so
%{_libdir}/mpich/lib/libnanosmpitrace-4.0.6.so
%{_libdir}/mpich/lib/libnanosmpitracecf-4.0.6.so
%{_libdir}/mpich/lib/libnanosmpitracef-4.0.6.so
%{_libdir}/mpich/lib/libnanostrace-4.0.6.so
%{_libdir}/mpich/lib/libompitrace-4.0.6.so
%{_libdir}/mpich/lib/libompitracecf-4.0.6.so
%{_libdir}/mpich/lib/libompitracef-4.0.6.so
%{_libdir}/mpich/lib/libomptrace-4.0.6.so
%{_libdir}/mpich/lib/libptmpitrace-4.0.6.so
%{_libdir}/mpich/lib/libptmpitracecf-4.0.6.so
%{_libdir}/mpich/lib/libptmpitracef-4.0.6.so
%{_libdir}/mpich/lib/libpttrace-4.0.6.so
%{_libdir}/mpich/lib/libseqtrace-4.0.6.so
%{_libdir}/mpich/lib/libsmpssmpitrace-4.0.6.so
%{_libdir}/mpich/lib/libsmpssmpitracecf-4.0.6.so
%{_libdir}/mpich/lib/libsmpssmpitracef-4.0.6.so
%{_libdir}/mpich/lib/libsmpsstrace-4.0.6.so
%dir %{_libdir}/mpich/libexec
%dir %{_libdir}/mpich/libexec/pyextrae
%{_libdir}/mpich/libexec/pyextrae/__init__.py
%dir %{_libdir}/mpich/libexec/pyextrae/common
%{_libdir}/mpich/libexec/pyextrae/common/__init__.py
%{_libdir}/mpich/libexec/pyextrae/common/extrae.py
%dir %{_libdir}/mpich/libexec/pyextrae/mpi
%{_libdir}/mpich/libexec/pyextrae/mpi/__init__.py
%dir %{_libdir}/mpich/libexec/pyextrae/multiprocessing
%{_libdir}/mpich/libexec/pyextrae/multiprocessing/__init__.py
%dir %{_libdir}/mpich/libexec/pyextrae/profile
%{_libdir}/mpich/libexec/pyextrae/profile/__init__.py
%dir %{_libdir}/mpich/libexec/pyextrae/pthreads
%{_libdir}/mpich/libexec/pyextrae/pthreads/__init__.py
%dir %{_libdir}/mpich/libexec/pyextrae/sequential
%{_libdir}/mpich/libexec/pyextrae/sequential/__init__.py

%files mpich-devel
%{_libdir}/mpich/include/Makefile.extrae_module
%{_libdir}/mpich/include/extrae.h
%{_libdir}/mpich/include/extrae_internals.h
%{_libdir}/mpich/include/extrae_module.f90
%{_libdir}/mpich/include/extrae_types.h
%{_libdir}/mpich/include/extrae_user_events.h
%{_libdir}/mpich/include/extrae_version.h
%{_libdir}/mpich/include/extraef.h
%{_libdir}/mpich/include/extraef_user_events.h
%{_libdir}/mpich/include/mpitrace_user_events.h
%{_libdir}/mpich/include/mpitracef_user_events.h
%{_libdir}/mpich/lib/libmpitrace.so
%{_libdir}/mpich/lib/libmpitracecf.so
%{_libdir}/mpich/lib/libmpitracef.so
%{_libdir}/mpich/lib/libnanosmpitrace.so
%{_libdir}/mpich/lib/libnanosmpitracecf.so
%{_libdir}/mpich/lib/libnanosmpitracef.so
%{_libdir}/mpich/lib/libnanostrace.so
%{_libdir}/mpich/lib/libompitrace.so
%{_libdir}/mpich/lib/libompitracecf.so
%{_libdir}/mpich/lib/libompitracef.so
%{_libdir}/mpich/lib/libomptrace.so
%{_libdir}/mpich/lib/libptmpitrace.so
%{_libdir}/mpich/lib/libptmpitracecf.so
%{_libdir}/mpich/lib/libptmpitracef.so
%{_libdir}/mpich/lib/libpttrace.so
%{_libdir}/mpich/lib/libseqtrace.so
%{_libdir}/mpich/lib/libsmpssmpitrace.so
%{_libdir}/mpich/lib/libsmpssmpitracecf.so
%{_libdir}/mpich/lib/libsmpssmpitracef.so
%{_libdir}/mpich/lib/libsmpsstrace.so

%files mpich-docs
%license %{name}-%{version}/COPYING
%dir %{_libdir}/mpich/share
%dir %{_libdir}/mpich/share/extrae
%dir %{_libdir}/mpich/share/extrae/example
%dir %{_libdir}/mpich/share/extrae/example/FORK
%{_libdir}/mpich/share/extrae/example/FORK/Makefile
%{_libdir}/mpich/share/extrae/example/FORK/Makefile.inc
%{_libdir}/mpich/share/extrae/example/FORK/README
%{_libdir}/mpich/share/extrae/example/FORK/extrae.xml
%{_libdir}/mpich/share/extrae/example/FORK/function-list
%{_libdir}/mpich/share/extrae/example/FORK/pi_forked.c
%{_libdir}/mpich/share/extrae/example/FORK/run_dyninst.sh
%dir %{_libdir}/mpich/share/extrae/example/MPI+OMP
%{_libdir}/mpich/share/extrae/example/MPI+OMP/Makefile.inc
%{_libdir}/mpich/share/extrae/example/MPI+OMP/README
%{_libdir}/mpich/share/extrae/example/MPI+OMP/extrae.xml
%dir %{_libdir}/mpich/share/extrae/example/MPI+OMP/ld-preload
%{_libdir}/mpich/share/extrae/example/MPI+OMP/ld-preload/Makefile
%{_libdir}/mpich/share/extrae/example/MPI+OMP/ld-preload/job.lsf
%{_libdir}/mpich/share/extrae/example/MPI+OMP/ld-preload/job.slurm
%{_libdir}/mpich/share/extrae/example/MPI+OMP/ld-preload/pi.c
%{_libdir}/mpich/share/extrae/example/MPI+OMP/ld-preload/trace.sh
%dir %{_libdir}/mpich/share/extrae/example/MPI+OMPSS
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/Makefile
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/Makefile.inc
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/extrae.xml
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/heat-mpi-ompss.c
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/heat.h
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/job.lsf
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/misc.c
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/solver-mpi-ompss.c
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/test.dat
%{_libdir}/mpich/share/extrae/example/MPI+OMPSS/trace.sh
%dir %{_libdir}/mpich/share/extrae/example/MPI
%{_libdir}/mpich/share/extrae/example/MPI/Makefile.inc
%{_libdir}/mpich/share/extrae/example/MPI/README
%{_libdir}/mpich/share/extrae/example/MPI/detailed_trace_basic.xml
%dir %{_libdir}/mpich/share/extrae/example/MPI/dyninst
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/Makefile
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/job.lsf
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/job.merge.lsf
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/job.merge.slurm
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/job.parallel_merge.lsf
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/job.parallel_merge.slurm
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/job.slurm
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/mpi_ping.f
%{_libdir}/mpich/share/extrae/example/MPI/dyninst/trace.sh
%{_libdir}/mpich/share/extrae/example/MPI/extrae.xml
%{_libdir}/mpich/share/extrae/example/MPI/extrae_bursts_1ms.xml
%{_libdir}/mpich/share/extrae/example/MPI/extrae_explained.xml
%dir %{_libdir}/mpich/share/extrae/example/MPI/ld-preload
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/Makefile
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/job.lsf
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/job.merge.lsf
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/job.merge.slurm
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/job.parallel_merge.lsf
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/job.parallel_merge.slurm
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/job.slurm
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/mpi2prv.sh
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/mpi_ping.f
%{_libdir}/mpich/share/extrae/example/MPI/ld-preload/trace.sh
%dir %{_libdir}/mpich/share/extrae/example/MPI/static
%{_libdir}/mpich/share/extrae/example/MPI/static/Makefile
%{_libdir}/mpich/share/extrae/example/MPI/static/job.lsf
%{_libdir}/mpich/share/extrae/example/MPI/static/job.merge.lsf
%{_libdir}/mpich/share/extrae/example/MPI/static/job.merge.slurm
%{_libdir}/mpich/share/extrae/example/MPI/static/job.parallel_merge.lsf
%{_libdir}/mpich/share/extrae/example/MPI/static/job.parallel_merge.slurm
%{_libdir}/mpich/share/extrae/example/MPI/static/job.slurm
%{_libdir}/mpich/share/extrae/example/MPI/static/mpi2prv.sh
%{_libdir}/mpich/share/extrae/example/MPI/static/mpi_ping.f
%{_libdir}/mpich/share/extrae/example/MPI/static/trace.sh
%{_libdir}/mpich/share/extrae/example/MPI/summarized_trace_basic.xml
%{_libdir}/mpich/share/extrae/example/Makefile.inc
%dir %{_libdir}/mpich/share/extrae/example/OMP
%{_libdir}/mpich/share/extrae/example/OMP/Makefile
%{_libdir}/mpich/share/extrae/example/OMP/Makefile.inc
%{_libdir}/mpich/share/extrae/example/OMP/README
%{_libdir}/mpich/share/extrae/example/OMP/extrae.xml
%{_libdir}/mpich/share/extrae/example/OMP/pi.c
%{_libdir}/mpich/share/extrae/example/OMP/pi_instrumented.c
%{_libdir}/mpich/share/extrae/example/OMP/run_dyninst.sh
%{_libdir}/mpich/share/extrae/example/OMP/run_instrumented.sh
%{_libdir}/mpich/share/extrae/example/OMP/run_ldpreload.sh
%dir %{_libdir}/mpich/share/extrae/example/OMPSS
%{_libdir}/mpich/share/extrae/example/OMPSS/Makefile
%{_libdir}/mpich/share/extrae/example/OMPSS/Makefile.inc
%{_libdir}/mpich/share/extrae/example/OMPSS/extrae.xml
%{_libdir}/mpich/share/extrae/example/OMPSS/heat-ompss.c
%{_libdir}/mpich/share/extrae/example/OMPSS/heat.h
%{_libdir}/mpich/share/extrae/example/OMPSS/job.lsf
%{_libdir}/mpich/share/extrae/example/OMPSS/misc.c
%{_libdir}/mpich/share/extrae/example/OMPSS/solver-ompss.c
%{_libdir}/mpich/share/extrae/example/OMPSS/test.dat
%{_libdir}/mpich/share/extrae/example/OMPSS/trace.sh
%dir %{_libdir}/mpich/share/extrae/example/PTHREAD
%{_libdir}/mpich/share/extrae/example/PTHREAD/Makefile
%{_libdir}/mpich/share/extrae/example/PTHREAD/Makefile.inc
%{_libdir}/mpich/share/extrae/example/PTHREAD/README
%{_libdir}/mpich/share/extrae/example/PTHREAD/extrae.xml
%{_libdir}/mpich/share/extrae/example/PTHREAD/pthread-example.c
%{_libdir}/mpich/share/extrae/example/PTHREAD/user-comms.c
%dir %{_libdir}/mpich/share/extrae/example/PYTHON
%{_libdir}/mpich/share/extrae/example/PYTHON/extrae.xml
%{_libdir}/mpich/share/extrae/example/PYTHON/function-list
%{_libdir}/mpich/share/extrae/example/PYTHON/run.sh
%{_libdir}/mpich/share/extrae/example/PYTHON/test.py
%dir %{_libdir}/mpich/share/extrae/example/SEQ
%{_libdir}/mpich/share/extrae/example/SEQ/Makefile
%{_libdir}/mpich/share/extrae/example/SEQ/Makefile.inc
%{_libdir}/mpich/share/extrae/example/SEQ/README
%{_libdir}/mpich/share/extrae/example/SEQ/extrae.xml
%{_libdir}/mpich/share/extrae/example/SEQ/function-list
%{_libdir}/mpich/share/extrae/example/SEQ/pi.c
%{_libdir}/mpich/share/extrae/example/SEQ/pi_instrumented.c
%{_libdir}/mpich/share/extrae/example/SEQ/pi_instrumented.f90
%{_libdir}/mpich/share/extrae/example/SEQ/run_dyninst.sh
%{_libdir}/mpich/share/extrae/example/SEQ/run_instrumented.sh
%{_libdir}/mpich/share/extrae/example/SEQ/run_instrumentedf.sh
%dir %{_libdir}/mpich/share/extrae/example/UNICORE
%dir %{_libdir}/mpich/share/extrae/example/UNICORE/MPI
%{_libdir}/mpich/share/extrae/example/UNICORE/MPI/extrae.xml
%dir %{_libdir}/mpich/share/extrae/example/UNICORE/SEQ
%{_libdir}/mpich/share/extrae/example/UNICORE/SEQ/extrae.xml
%dir %{_libdir}/mpich/share/extrae/tests
%dir %{_libdir}/mpich/share/extrae/tests/overhead
%{_libdir}/mpich/share/extrae/tests/overhead/JavaEvent.java
%{_libdir}/mpich/share/extrae/tests/overhead/JavaFakeRoutine.java
%{_libdir}/mpich/share/extrae/tests/overhead/JavaNEvent4.java
%{_libdir}/mpich/share/extrae/tests/overhead/Makefile
%{_libdir}/mpich/share/extrae/tests/overhead/extrae.xml
%{_libdir}/mpich/share/extrae/tests/overhead/extrae_event.c
%{_libdir}/mpich/share/extrae/tests/overhead/extrae_eventandcounters.c
%{_libdir}/mpich/share/extrae/tests/overhead/extrae_get_caller1.c
%{_libdir}/mpich/share/extrae/tests/overhead/extrae_get_caller6.c
%{_libdir}/mpich/share/extrae/tests/overhead/extrae_nevent4.c
%{_libdir}/mpich/share/extrae/tests/overhead/extrae_trace_callers.c
%{_libdir}/mpich/share/extrae/tests/overhead/extrae_user_function.c
%{_libdir}/mpich/share/extrae/tests/overhead/extraej.xml
%{_libdir}/mpich/share/extrae/tests/overhead/extraej_functionlist
%{_libdir}/mpich/share/extrae/tests/overhead/ia32_rdtsc_clock.c
%{_libdir}/mpich/share/extrae/tests/overhead/papi_read1.c
%{_libdir}/mpich/share/extrae/tests/overhead/papi_read4.c
%{_libdir}/mpich/share/extrae/tests/overhead/posix_clock.c
%{_libdir}/mpich/share/extrae/tests/overhead/ppc_clock.c
%{_libdir}/mpich/share/extrae/tests/overhead/run_overhead_tests.sh

%files openmpi
%license %{name}-%{version}/COPYING
%doc %{name}-%{version}/README
%doc %{name}-%{version}/ChangeLog
%doc %{name}-%{version}/AUTHORS
%{_libdir}/openmpi/bin/extrae-cmd
%{_libdir}/openmpi/bin/extrae-header
%{_libdir}/openmpi/bin/extrae-loader
%{_libdir}/openmpi/bin/extrae-uncore
%{_libdir}/openmpi/bin/extrae-uncore.py
%{_libdir}/openmpi/bin/extrae_static
%{_libdir}/openmpi/bin/genmpits
%{_libdir}/openmpi/bin/mpi2dim
%{_libdir}/openmpi/bin/mpi2prv
%{_libdir}/openmpi/bin/mpimpi2dim
%{_libdir}/openmpi/bin/mpimpi2prv
%{_libdir}/openmpi/bin/papi_best_set
%{_libdir}/openmpi/bin/reducempit
%{_libdir}/openmpi/bin/uncore-service-mpi
%{_libdir}/openmpi/bin/uncore-service-seq
%dir %{_libdir}/openmpi/etc
%{_libdir}/openmpi/etc/configured.sh
%{_libdir}/openmpi/etc/extrae-vars.sh
%{_libdir}/openmpi/etc/extrae.sh
%{_libdir}/openmpi/etc/extrae_uncore_template.xml
%{_libdir}/openmpi/lib/libmpitrace-4.0.6.so
%{_libdir}/openmpi/lib/libmpitracecf-4.0.6.so
%{_libdir}/openmpi/lib/libmpitracef-4.0.6.so
%{_libdir}/openmpi/lib/libnanosmpitrace-4.0.6.so
%{_libdir}/openmpi/lib/libnanosmpitracecf-4.0.6.so
%{_libdir}/openmpi/lib/libnanosmpitracef-4.0.6.so
%{_libdir}/openmpi/lib/libnanostrace-4.0.6.so
%{_libdir}/openmpi/lib/libompitrace-4.0.6.so
%{_libdir}/openmpi/lib/libompitracecf-4.0.6.so
%{_libdir}/openmpi/lib/libompitracef-4.0.6.so
%{_libdir}/openmpi/lib/libomptrace-4.0.6.so
%{_libdir}/openmpi/lib/libptmpitrace-4.0.6.so
%{_libdir}/openmpi/lib/libptmpitracecf-4.0.6.so
%{_libdir}/openmpi/lib/libptmpitracef-4.0.6.so
%{_libdir}/openmpi/lib/libpttrace-4.0.6.so
%{_libdir}/openmpi/lib/libseqtrace-4.0.6.so
%{_libdir}/openmpi/lib/libsmpssmpitrace-4.0.6.so
%{_libdir}/openmpi/lib/libsmpssmpitracecf-4.0.6.so
%{_libdir}/openmpi/lib/libsmpssmpitracef-4.0.6.so
%{_libdir}/openmpi/lib/libsmpsstrace-4.0.6.so
%dir %{_libdir}/openmpi/libexec
%dir %{_libdir}/openmpi/libexec/pyextrae
%{_libdir}/openmpi/libexec/pyextrae/__init__.py
%dir %{_libdir}/openmpi/libexec/pyextrae/common
%{_libdir}/openmpi/libexec/pyextrae/common/__init__.py
%{_libdir}/openmpi/libexec/pyextrae/common/extrae.py
%dir %{_libdir}/openmpi/libexec/pyextrae/mpi
%{_libdir}/openmpi/libexec/pyextrae/mpi/__init__.py
%dir %{_libdir}/openmpi/libexec/pyextrae/multiprocessing
%{_libdir}/openmpi/libexec/pyextrae/multiprocessing/__init__.py
%dir %{_libdir}/openmpi/libexec/pyextrae/profile
%{_libdir}/openmpi/libexec/pyextrae/profile/__init__.py
%dir %{_libdir}/openmpi/libexec/pyextrae/pthreads
%{_libdir}/openmpi/libexec/pyextrae/pthreads/__init__.py
%dir %{_libdir}/openmpi/libexec/pyextrae/sequential
%{_libdir}/openmpi/libexec/pyextrae/sequential/__init__.py

%files openmpi-devel
%{_libdir}/openmpi/include/Makefile.extrae_module
%{_libdir}/openmpi/include/extrae.h
%{_libdir}/openmpi/include/extrae_internals.h
%{_libdir}/openmpi/include/extrae_module.f90
%{_libdir}/openmpi/include/extrae_types.h
%{_libdir}/openmpi/include/extrae_user_events.h
%{_libdir}/openmpi/include/extrae_version.h
%{_libdir}/openmpi/include/extraef.h
%{_libdir}/openmpi/include/extraef_user_events.h
%{_libdir}/openmpi/include/mpitrace_user_events.h
%{_libdir}/openmpi/include/mpitracef_user_events.h
%{_libdir}/openmpi/lib/libmpitrace.so
%{_libdir}/openmpi/lib/libmpitracecf.so
%{_libdir}/openmpi/lib/libmpitracef.so
%{_libdir}/openmpi/lib/libnanosmpitrace.so
%{_libdir}/openmpi/lib/libnanosmpitracecf.so
%{_libdir}/openmpi/lib/libnanosmpitracef.so
%{_libdir}/openmpi/lib/libnanostrace.so
%{_libdir}/openmpi/lib/libompitrace.so
%{_libdir}/openmpi/lib/libompitracecf.so
%{_libdir}/openmpi/lib/libompitracef.so
%{_libdir}/openmpi/lib/libomptrace.so
%{_libdir}/openmpi/lib/libptmpitrace.so
%{_libdir}/openmpi/lib/libptmpitracecf.so
%{_libdir}/openmpi/lib/libptmpitracef.so
%{_libdir}/openmpi/lib/libpttrace.so
%{_libdir}/openmpi/lib/libseqtrace.so
%{_libdir}/openmpi/lib/libsmpssmpitrace.so
%{_libdir}/openmpi/lib/libsmpssmpitracecf.so
%{_libdir}/openmpi/lib/libsmpssmpitracef.so
%{_libdir}/openmpi/lib/libsmpsstrace.so

%files openmpi-docs
%license %{name}-%{version}/COPYING
%dir %{_libdir}/openmpi/share/extrae
%dir %{_libdir}/openmpi/share/extrae/example
%dir %{_libdir}/openmpi/share/extrae/example/FORK
%{_libdir}/openmpi/share/extrae/example/FORK/Makefile
%{_libdir}/openmpi/share/extrae/example/FORK/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/FORK/README
%{_libdir}/openmpi/share/extrae/example/FORK/extrae.xml
%{_libdir}/openmpi/share/extrae/example/FORK/function-list
%{_libdir}/openmpi/share/extrae/example/FORK/pi_forked.c
%{_libdir}/openmpi/share/extrae/example/FORK/run_dyninst.sh
%dir %{_libdir}/openmpi/share/extrae/example/MPI+OMP
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/README
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/extrae.xml
%dir %{_libdir}/openmpi/share/extrae/example/MPI+OMP/ld-preload
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/ld-preload/Makefile
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/ld-preload/job.lsf
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/ld-preload/job.slurm
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/ld-preload/pi.c
%{_libdir}/openmpi/share/extrae/example/MPI+OMP/ld-preload/trace.sh
%dir %{_libdir}/openmpi/share/extrae/example/MPI+OMPSS
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/Makefile
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/extrae.xml
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/heat-mpi-ompss.c
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/heat.h
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/job.lsf
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/misc.c
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/solver-mpi-ompss.c
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/test.dat
%{_libdir}/openmpi/share/extrae/example/MPI+OMPSS/trace.sh
%dir %{_libdir}/openmpi/share/extrae/example/MPI
%{_libdir}/openmpi/share/extrae/example/MPI/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/MPI/README
%{_libdir}/openmpi/share/extrae/example/MPI/detailed_trace_basic.xml
%dir %{_libdir}/openmpi/share/extrae/example/MPI/dyninst
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/Makefile
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/job.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/job.merge.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/job.merge.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/job.parallel_merge.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/job.parallel_merge.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/job.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/mpi_ping.f
%{_libdir}/openmpi/share/extrae/example/MPI/dyninst/trace.sh
%{_libdir}/openmpi/share/extrae/example/MPI/extrae.xml
%{_libdir}/openmpi/share/extrae/example/MPI/extrae_bursts_1ms.xml
%{_libdir}/openmpi/share/extrae/example/MPI/extrae_explained.xml
%dir %{_libdir}/openmpi/share/extrae/example/MPI/ld-preload
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/Makefile
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/job.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/job.merge.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/job.merge.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/job.parallel_merge.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/job.parallel_merge.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/job.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/mpi2prv.sh
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/mpi_ping.f
%{_libdir}/openmpi/share/extrae/example/MPI/ld-preload/trace.sh
%dir %{_libdir}/openmpi/share/extrae/example/MPI/static
%{_libdir}/openmpi/share/extrae/example/MPI/static/Makefile
%{_libdir}/openmpi/share/extrae/example/MPI/static/job.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/static/job.merge.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/static/job.merge.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/static/job.parallel_merge.lsf
%{_libdir}/openmpi/share/extrae/example/MPI/static/job.parallel_merge.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/static/job.slurm
%{_libdir}/openmpi/share/extrae/example/MPI/static/mpi2prv.sh
%{_libdir}/openmpi/share/extrae/example/MPI/static/mpi_ping.f
%{_libdir}/openmpi/share/extrae/example/MPI/static/trace.sh
%{_libdir}/openmpi/share/extrae/example/MPI/summarized_trace_basic.xml
%{_libdir}/openmpi/share/extrae/example/Makefile.inc
%dir %{_libdir}/openmpi/share/extrae/example/OMP
%{_libdir}/openmpi/share/extrae/example/OMP/Makefile
%{_libdir}/openmpi/share/extrae/example/OMP/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/OMP/README
%{_libdir}/openmpi/share/extrae/example/OMP/extrae.xml
%{_libdir}/openmpi/share/extrae/example/OMP/pi.c
%{_libdir}/openmpi/share/extrae/example/OMP/pi_instrumented.c
%{_libdir}/openmpi/share/extrae/example/OMP/run_dyninst.sh
%{_libdir}/openmpi/share/extrae/example/OMP/run_instrumented.sh
%{_libdir}/openmpi/share/extrae/example/OMP/run_ldpreload.sh
%dir %{_libdir}/openmpi/share/extrae/example/OMPSS
%{_libdir}/openmpi/share/extrae/example/OMPSS/Makefile
%{_libdir}/openmpi/share/extrae/example/OMPSS/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/OMPSS/extrae.xml
%{_libdir}/openmpi/share/extrae/example/OMPSS/heat-ompss.c
%{_libdir}/openmpi/share/extrae/example/OMPSS/heat.h
%{_libdir}/openmpi/share/extrae/example/OMPSS/job.lsf
%{_libdir}/openmpi/share/extrae/example/OMPSS/misc.c
%{_libdir}/openmpi/share/extrae/example/OMPSS/solver-ompss.c
%{_libdir}/openmpi/share/extrae/example/OMPSS/test.dat
%{_libdir}/openmpi/share/extrae/example/OMPSS/trace.sh
%dir %{_libdir}/openmpi/share/extrae/example/PTHREAD
%{_libdir}/openmpi/share/extrae/example/PTHREAD/Makefile
%{_libdir}/openmpi/share/extrae/example/PTHREAD/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/PTHREAD/README
%{_libdir}/openmpi/share/extrae/example/PTHREAD/extrae.xml
%{_libdir}/openmpi/share/extrae/example/PTHREAD/pthread-example.c
%{_libdir}/openmpi/share/extrae/example/PTHREAD/user-comms.c
%dir %{_libdir}/openmpi/share/extrae/example/PYTHON
%{_libdir}/openmpi/share/extrae/example/PYTHON/extrae.xml
%{_libdir}/openmpi/share/extrae/example/PYTHON/function-list
%{_libdir}/openmpi/share/extrae/example/PYTHON/run.sh
%{_libdir}/openmpi/share/extrae/example/PYTHON/test.py
%dir %{_libdir}/openmpi/share/extrae/example/SEQ
%{_libdir}/openmpi/share/extrae/example/SEQ/Makefile
%{_libdir}/openmpi/share/extrae/example/SEQ/Makefile.inc
%{_libdir}/openmpi/share/extrae/example/SEQ/README
%{_libdir}/openmpi/share/extrae/example/SEQ/extrae.xml
%{_libdir}/openmpi/share/extrae/example/SEQ/function-list
%{_libdir}/openmpi/share/extrae/example/SEQ/pi.c
%{_libdir}/openmpi/share/extrae/example/SEQ/pi_instrumented.c
%{_libdir}/openmpi/share/extrae/example/SEQ/pi_instrumented.f90
%{_libdir}/openmpi/share/extrae/example/SEQ/run_dyninst.sh
%{_libdir}/openmpi/share/extrae/example/SEQ/run_instrumented.sh
%{_libdir}/openmpi/share/extrae/example/SEQ/run_instrumentedf.sh
%dir %{_libdir}/openmpi/share/extrae/example/UNICORE
%dir %{_libdir}/openmpi/share/extrae/example/UNICORE/MPI
%{_libdir}/openmpi/share/extrae/example/UNICORE/MPI/extrae.xml
%dir %{_libdir}/openmpi/share/extrae/example/UNICORE/SEQ
%{_libdir}/openmpi/share/extrae/example/UNICORE/SEQ/extrae.xml
%dir %{_libdir}/openmpi/share/extrae/tests
%dir %{_libdir}/openmpi/share/extrae/tests/overhead
%{_libdir}/openmpi/share/extrae/tests/overhead/JavaEvent.java
%{_libdir}/openmpi/share/extrae/tests/overhead/JavaFakeRoutine.java
%{_libdir}/openmpi/share/extrae/tests/overhead/JavaNEvent4.java
%{_libdir}/openmpi/share/extrae/tests/overhead/Makefile
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae.xml
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae_event.c
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae_eventandcounters.c
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae_get_caller1.c
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae_get_caller6.c
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae_nevent4.c
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae_trace_callers.c
%{_libdir}/openmpi/share/extrae/tests/overhead/extrae_user_function.c
%{_libdir}/openmpi/share/extrae/tests/overhead/extraej.xml
%{_libdir}/openmpi/share/extrae/tests/overhead/extraej_functionlist
%{_libdir}/openmpi/share/extrae/tests/overhead/ia32_rdtsc_clock.c
%{_libdir}/openmpi/share/extrae/tests/overhead/papi_read1.c
%{_libdir}/openmpi/share/extrae/tests/overhead/papi_read4.c
%{_libdir}/openmpi/share/extrae/tests/overhead/posix_clock.c
%{_libdir}/openmpi/share/extrae/tests/overhead/ppc_clock.c
%{_libdir}/openmpi/share/extrae/tests/overhead/run_overhead_tests.sh

%changelog
* Sun Nov 12 2023 Benson Muite <benson_muite@emailplus.org> - 4.0.6-1
- Initial packaging
